import gmsh

# Initialize session
gmsh.initialize()
gmsh.option.setNumber("General.Terminal", 1)
gmsh.option.setNumber("Geometry.AutoCoherence", 2)
gmsh.option.setNumber("Mesh.CharacteristicLengthFactor", 0.1) # frontal
gmsh.option.setNumber("Mesh.CharacteristicLengthMax", 0.1) # frontal

##############################################################
# Add new model
gmsh.model.add('merged-shells')

# Add STLs
gmsh.merge('inclusion-1.stl')
gmsh.merge('inclusion-2.stl')

surfaces = gmsh.model.getEntities(2)
surfaces = [surfaces[i][1] for i in range(len(surfaces))]

# Create surface loop
sl1 = gmsh.model.geo.addSurfaceLoop([surfaces])

# Create volume enclosed by surface loop
v1 = gmsh.model.geo.addVolume([sl1])

# Synchronize model
gmsh.model.geo.synchronize()

# # Create mesh
gmsh.model.mesh.generate(3)
gmsh.model.mesh.optimize("Netgen", True)


# Synchronize model
gmsh.model.geo.synchronize()

###############################################################################################################################################

# Save file
gmsh.write('STLs2-thin-lens-duplicated-python.msh')
gmsh.write('STLs2-thin-lens-duplicated-python.inp')

# End session
gmsh.finalize()
