import gmsh

# Initialize session
gmsh.initialize()
gmsh.option.setNumber("General.Terminal", 1)
gmsh.option.setNumber("Geometry.AutoCoherence", 2)
gmsh.option.setNumber("Mesh.CharacteristicLengthFactor", 0.1) # frontal
gmsh.option.setNumber("Mesh.CharacteristicLengthMax", 0.1) # frontal

##############################################################
# Add new model
gmsh.model.add('merged-shells')

# Include STL and retrieve surfaces
gmsh.merge('inclusion-manual.stl')

surface = gmsh.model.getEntities(2)
surface = surface[0][1]

# Create surface loop
sl1 = gmsh.model.geo.addSurfaceLoop([surface])

# Create volume enclosed by surface loop
v1 = gmsh.model.geo.addVolume([sl1])

# Synchronize model
gmsh.model.geo.synchronize()

# # Create mesh
gmsh.model.mesh.generate(3)
gmsh.model.mesh.optimize("Netgen", True)


# Synchronize model
gmsh.model.geo.synchronize()

###############################################################################################################################################

# Save file
gmsh.write('thin-lens-duplicate-python.msh')
gmsh.write('thin-lens-duplicate-python.inp')

# End session
gmsh.finalize()
